@@ -54,7 +54,7 @@ typedef struct
 static GladeEditableIface *parent_editable_iface;
 
 G_DEFINE_TYPE_WITH_CODE (GladeCellRendererEditor, glade_cell_renderer_editor,
-                         GTK_TYPE_VBOX,
+                         GTK_TYPE_BOX,
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
                                                 glade_cell_renderer_editor_editable_init));
 
@@ -72,6 +72,8 @@ glade_cell_renderer_editor_class_init (GladeCellRendererEditorClass * klass)
 static void
 glade_cell_renderer_editor_init (GladeCellRendererEditor * self)
 {
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (self),
+				  GTK_ORIENTATION_VERTICAL);
 }
 
 static void
